/*!\file PowerVariogram.c
 * \brief: implementation of the PowerVariogram object
 */

#ifdef HAVE_CONFIG_H
	#include <config.h>
#else
#error "Cannot compile with HAVE_CONFIG_H symbol! run configure first!"
#endif

#include <stdio.h>
#include <string.h>
#include "../objects.h"
#include "../../EnumDefinitions/EnumDefinitions.h"
#include "../../shared/shared.h"
#include "../../include/include.h"

/*PowerVariogram constructors and destructor*/
/*FUNCTION PowerVariogram::PowerVariogram(){{{1*/
PowerVariogram::PowerVariogram(){
	this->nugget = 0.2;
	this->slope  = 1.;
	this->power  = 1.;
	return;
}
/*}}}*/
/*FUNCTION PowerVariogram::PowerVariogram(Options* options){{{1*/
PowerVariogram::PowerVariogram(Options* options){

	/*Defaults*/
	this->nugget = 0.2;
	this->slope  = 1.;
	this->power  = 1.;

	/*Overwrite from options*/
	if(options->GetOption("nugget")) options->Get(&this->nugget,"nugget");
	if(options->GetOption("slope"))  options->Get(&this->slope,"slope");
	if(options->GetOption("power"))  options->Get(&this->power,"power");

	/*Checks*/
	if(power<=0 || power>=2) _error_("power must be betwwen 0 and 2 (0 < power < 2)");
	if(slope<=0) _error_("slope must be positive");
}
/*}}}*/
/*FUNCTION PowerVariogram::~PowerVariogram(){{{1*/
PowerVariogram::~PowerVariogram(){
	return;
}
/*}}}*/

/*Object virtual functions definitions:*/
/*FUNCTION PowerVariogram::Echo {{{1*/
void PowerVariogram::Echo(void){
	printf("PowerVariogram\n");
	printf("   nugget: %g\n",this->nugget);
	printf("   slope : %g\n",this->slope);
	printf("   power : %g\n",this->power);
}
/*}}}*/

/*Variogram function*/
/*FUNCTION PowerVariogram::SemiVariogram{{{1*/
double PowerVariogram::SemiVariogram(double deltax,double deltay){
	/*http://en.wikipedia.org/wiki/Variogram*/
	double h,gamma;

	/*Calculate length square*/
	h=sqrt(pow(deltax,2.)+pow(deltay,2.));

	/*return semi-variogram*/
	gamma = this->nugget + this->slope*pow(h,this->power);

	return gamma;
}
/*}}}*/
